==> lxqt-config_0.14.1.orig.tar.xz: lxqt-config-0.14.1/lxqt-config-brightness/translations/lxqt-config-brightness_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>明るさの設定</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="24"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Use arrow keys to change settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;バックライトと明るさの設定:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;設定の変更に矢印キーを使用する。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="41"/>
        <source>Require confirmation after settings change</source>
        <translation>設定の変更の際に確認する</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="88"/>
        <source>Brightness settings changed</source>
        <translation>明るさの設定が変更されました</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="89"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>確認。設定は正しいですか?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;出力:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="67"/>
        <source>Right click to reset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-config_0.15.0.orig.tar.xz: lxqt-config-0.15.0/lxqt-config-brightness/translations/lxqt-config-brightness_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>明るさの設定</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="24"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Use arrow keys to change settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;バックライトと明るさの設定:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;矢印キーで設定を変更できます。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="41"/>
        <source>Require confirmation after settings change</source>
        <translation>設定の変更の際に確認する</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="88"/>
        <source>Brightness settings changed</source>
        <translation>明るさの設定が変更されました</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="89"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>確認です。設定しますか？</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;出力:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="67"/>
        <source>Right click to reset</source>
        <translation>右クリックでリセットします</translation>
    </message>
</context>
</TS>
